@@ -15,6 +15,7 @@ from botocore.exceptions import (
     ProxyConnectionError,
 )
 from botocore.httpsession import (
+    BUFFER_SIZE,
     ProxyConfiguration,
     URLLib3Session,
     get_cert_path,
@@ -156,6 +157,8 @@ class TestURLLib3Session(unittest.TestCase):
             'cert_file': None,
             'key_file': None,
         }
+        if BUFFER_SIZE:
+            call_kwargs['blocksize'] = BUFFER_SIZE
         call_kwargs.update(assert_kwargs)
         manager.assert_called_with(*assert_args, **call_kwargs)
 
